Package: seasonalityPlot
Type: Package
Title: Seasonality Variation Plots of Stock Prices and Cryptocurrencies
Version: 1.3.1
Authors@R: c(person("Satoshi", "Kume", 
             role = c("aut", "cre"),
             email = "satoshi.kume.1984@gmail.com"))
Description: The price action at any given time is determined by investor 
  sentiment and market conditions. Although there is no established principle, 
  over a long period of time, things often move with a certain periodicity.
  This is sometimes referred to as anomaly. 
  The seasonPlot() function in this package calculates and visualizes the 
  average value of price movements over a year for any given period. 
  In addition, the monthly increase or decrease in price movement is 
  represented with a colored background. 
  This seasonPlot() function can use the same symbols as the 'quantmod' package 
  (e.g. ^IXIC, ^DJI, SPY, BTC-USD, and ETH-USD etc). 
Depends: R (>= 4.0.0)
Imports: magrittr, quantmod, dygraphs, plotrix, htmltools, grDevices,
        graphics, zoo, lubridate, crypto2, TTR, assertthat
Suggests: testthat
License: Artistic-2.0
Encoding: UTF-8
URL: https://github.com/kumeS/seasonalityPlot,
        https://kumes.github.io/seasonalityPlot/,
        https://skume-seasonalityplot.hf.space/__docs__/#/
BugReports: https://github.com/kumeS/seasonalityPlot/issues
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2024-09-25 09:42:17 UTC; sas
Author: Satoshi Kume [aut, cre]
Maintainer: Satoshi Kume <satoshi.kume.1984@gmail.com>
Repository: CRAN
Date/Publication: 2024-09-25 12:00:02 UTC
Built: R 4.6.0; ; 2026-04-30 03:09:15 UTC; unix
