#^DJI (Dow Jones Industrial Average)
DJI <- list(
Symbols="^DJI",
StartYear=2010,
EndYear=2020,
LineColor=1,
xlab="Month",
BackgroundMode=TRUE,
alpha=0.05,
OutputData=FALSE,
Save=FALSE,
output_width=1000,
output_height=700,
family="Helvetica",
PlotAll=FALSE
)

#attach(DJI)
